==> openshift-model-operator-6.8.0-sources.jar: io/fabric8/openshift/api/model/operator/v1/FeaturesMigrationFluent.java <==
package io.fabric8.openshift.api.model.operator.v1;

import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.String;
import java.lang.Boolean;
import java.util.Map;
import java.util.LinkedHashMap;

 /**
  * Generated
  */
  @SuppressWarnings(value = "unchecked")
  public class FeaturesMigrationFluent<A extends FeaturesMigrationFluent<A>> extends BaseFluent<A>{
  public FeaturesMigrationFluent() {
  }
  public FeaturesMigrationFluent(FeaturesMigration instance) {
    instance = (instance != null ? instance : new FeaturesMigration());

    if (instance != null) {
      this.withEgressFirewall(instance.getEgressFirewall());
      this.withEgressIP(instance.getEgressIP());
      this.withMulticast(instance.getMulticast());
      this.withEgressFirewall(instance.getEgressFirewall());
      this.withEgressIP(instance.getEgressIP());
      this.withMulticast(instance.getMulticast());
      this.withAdditionalProperties(instance.getAdditionalProperties());
    }
  }
  private Boolean egressFirewall;
  private Boolean egressIP;
  private Boolean multicast;
  private Map<String,Object> additionalProperties;
  public Boolean getEgressFirewall() {
    return this.egressFirewall;
  }
  public A withEgressFirewall(Boolean egressFirewall) {
    this.egressFirewall=egressFirewall; return (A) this;
  }
  public boolean hasEgressFirewall() {
    return this.egressFirewall != null;
  }
  public Boolean getEgressIP() {
    return this.egressIP;
  }
  public A withEgressIP(Boolean egressIP) {
    this.egressIP=egressIP; return (A) this;
  }
  public boolean hasEgressIP() {
    return this.egressIP != null;
  }
  public Boolean getMulticast() {
    return this.multicast;
  }
  public A withMulticast(Boolean multicast) {
    this.multicast=multicast; return (A) this;
  }
  public boolean hasMulticast() {
    return this.multicast != null;
  }
  public A addToAdditionalProperties(String key,Object value) {
    if(this.additionalProperties == null && key != null && value != null) { this.additionalProperties = new LinkedHashMap(); }
    if(key != null && value != null) {this.additionalProperties.put(key, value);} return (A)this;
  }
  public A addToAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null && map != null) { this.additionalProperties = new LinkedHashMap(); }
    if(map != null) { this.additionalProperties.putAll(map);} return (A)this;
  }
  public A removeFromAdditionalProperties(String key) {
    if(this.additionalProperties == null) { return (A) this; }
    if(key != null && this.additionalProperties != null) {this.additionalProperties.remove(key);} return (A)this;
  }
  public A removeFromAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.additionalProperties != null){this.additionalProperties.remove(key);}}} return (A)this;
  }
  public Map<String,Object> getAdditionalProperties() {
    return this.additionalProperties;
  }
  public <K,V>A withAdditionalProperties(Map<String,Object> additionalProperties) {
    if (additionalProperties == null) { this.additionalProperties =  null;} else {this.additionalProperties = new LinkedHashMap(additionalProperties);} return (A) this;
  }
  public boolean hasAdditionalProperties() {
    return this.additionalProperties != null;
  }
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    FeaturesMigrationFluent that = (FeaturesMigrationFluent) o;
    if (!java.util.Objects.equals(egressFirewall, that.egressFirewall)) return false;

    if (!java.util.Objects.equals(egressIP, that.egressIP)) return false;

    if (!java.util.Objects.equals(multicast, that.multicast)) return false;

    if (!java.util.Objects.equals(additionalProperties, that.additionalProperties)) return false;

    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(egressFirewall,  egressIP,  multicast,  additionalProperties,  super.hashCode());
  }
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (egressFirewall != null) { sb.append("egressFirewall:"); sb.append(egressFirewall + ","); }
    if (egressIP != null) { sb.append("egressIP:"); sb.append(egressIP + ","); }
    if (multicast != null) { sb.append("multicast:"); sb.append(multicast + ","); }
    if (additionalProperties != null && !additionalProperties.isEmpty()) { sb.append("additionalProperties:"); sb.append(additionalProperties); }
    sb.append("}");
    return sb.toString();
  }
  public A withEgressFirewall() {
    return withEgressFirewall(true);
  }
  public A withEgressIP() {
    return withEgressIP(true);
  }
  public A withMulticast() {
    return withMulticast(true);
  }
  
}

==> openshift-model-operator-6.9.0-sources.jar: io/fabric8/openshift/api/model/operator/v1/FeaturesMigrationFluent.java <==
package io.fabric8.openshift.api.model.operator.v1;

import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.String;
import java.lang.Boolean;
import java.util.Map;
import java.util.LinkedHashMap;

/**
 * Generated
 */
@SuppressWarnings("unchecked")
public class FeaturesMigrationFluent<A extends FeaturesMigrationFluent<A>> extends BaseFluent<A>{
  public FeaturesMigrationFluent() {
  }
  
  public FeaturesMigrationFluent(FeaturesMigration instance) {
    this.copyInstance(instance);
  }
  private Boolean egressFirewall;
  private Boolean egressIP;
  private Boolean multicast;
  private Map<String,Object> additionalProperties;
  
  protected void copyInstance(FeaturesMigration instance) {
    instance = (instance != null ? instance : new FeaturesMigration());
  
    if (instance != null) {
        this.withEgressFirewall(instance.getEgressFirewall());
        this.withEgressIP(instance.getEgressIP());
        this.withMulticast(instance.getMulticast());
        this.withEgressFirewall(instance.getEgressFirewall());
        this.withEgressIP(instance.getEgressIP());
        this.withMulticast(instance.getMulticast());
        this.withAdditionalProperties(instance.getAdditionalProperties());
      }
  }
  
  public Boolean getEgressFirewall() {
    return this.egressFirewall;
  }
  
  public A withEgressFirewall(Boolean egressFirewall) {
    this.egressFirewall=egressFirewall; return (A) this;
  }
  
  public boolean hasEgressFirewall() {
    return this.egressFirewall != null;
  }
  
  public Boolean getEgressIP() {
    return this.egressIP;
  }
  
  public A withEgressIP(Boolean egressIP) {
    this.egressIP=egressIP; return (A) this;
  }
  
  public boolean hasEgressIP() {
    return this.egressIP != null;
  }
  
  public Boolean getMulticast() {
    return this.multicast;
  }
  
  public A withMulticast(Boolean multicast) {
    this.multicast=multicast; return (A) this;
  }
  
  public boolean hasMulticast() {
    return this.multicast != null;
  }
  
  public A addToAdditionalProperties(String key,Object value) {
    if(this.additionalProperties == null && key != null && value != null) { this.additionalProperties = new LinkedHashMap(); }
    if(key != null && value != null) {this.additionalProperties.put(key, value);} return (A)this;
  }
  
  public A addToAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null && map != null) { this.additionalProperties = new LinkedHashMap(); }
    if(map != null) { this.additionalProperties.putAll(map);} return (A)this;
  }
  
  public A removeFromAdditionalProperties(String key) {
    if(this.additionalProperties == null) { return (A) this; }
    if(key != null && this.additionalProperties != null) {this.additionalProperties.remove(key);} return (A)this;
  }
  
  public A removeFromAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.additionalProperties != null){this.additionalProperties.remove(key);}}} return (A)this;
  }
  
  public Map<String,Object> getAdditionalProperties() {
    return this.additionalProperties;
  }
  
  public <K,V>A withAdditionalProperties(Map<String,Object> additionalProperties) {
    if (additionalProperties == null) { this.additionalProperties =  null;} else {this.additionalProperties = new LinkedHashMap(additionalProperties);} return (A) this;
  }
  
  public boolean hasAdditionalProperties() {
    return this.additionalProperties != null;
  }
  
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    FeaturesMigrationFluent that = (FeaturesMigrationFluent) o;
    if (!java.util.Objects.equals(egressFirewall, that.egressFirewall)) return false;
  
    if (!java.util.Objects.equals(egressIP, that.egressIP)) return false;
  
    if (!java.util.Objects.equals(multicast, that.multicast)) return false;
  
    if (!java.util.Objects.equals(additionalProperties, that.additionalProperties)) return false;
  
    return true;
  }
  
  public int hashCode() {
    return java.util.Objects.hash(egressFirewall,  egressIP,  multicast,  additionalProperties,  super.hashCode());
  }
  
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (egressFirewall != null) { sb.append("egressFirewall:"); sb.append(egressFirewall + ","); }
    if (egressIP != null) { sb.append("egressIP:"); sb.append(egressIP + ","); }
    if (multicast != null) { sb.append("multicast:"); sb.append(multicast + ","); }
    if (additionalProperties != null && !additionalProperties.isEmpty()) { sb.append("additionalProperties:"); sb.append(additionalProperties); }
    sb.append("}");
    return sb.toString();
  }
  
  public A withEgressFirewall() {
    return withEgressFirewall(true);
  }
  
  public A withEgressIP() {
    return withEgressIP(true);
  }
  
  public A withMulticast() {
    return withMulticast(true);
  }
  

}
